@@ -1,5 +1,5 @@
 """
-Module handes Dicord functionality
+Module handles Dicord functionality
 """
 import json
 import requests
